headerValue property
String
get
headerValue
Returns the value of the Authorization header as a string.
Implementation
String get headerValue;
Returns the value of the Authorization header as a string.
String get headerValue;