mustRevalidate property
Specifies that the response must be revalidated with the origin server before use.
Implementation
final bool mustRevalidate;
Specifies that the response must be revalidated with the origin server before use.
final bool mustRevalidate;