onlyIfCached property
Indicates that the response should only be returned from cache and not fetch from origin.
Implementation
final bool onlyIfCached;
Indicates that the response should only be returned from cache and not fetch from origin.
final bool onlyIfCached;