privateCache property
Specifies that the resource is only for private use (specific to a single user).
Implementation
final bool? privateCache;
Specifies that the resource is only for private use (specific to a single user).
final bool? privateCache;