staleIfError property
Specifies the maximum amount of time (in seconds) a stale resource can be used while the cache is being refreshed.
Implementation
final int? staleIfError;
Specifies the maximum amount of time (in seconds) a stale resource can be used while the cache is being refreshed.
final int? staleIfError;