FileInfo class

Cached file information including MIME type, file stats, and ETag.

Constructors

FileInfo(File file, MimeType? mimeType, FileStat stat, String etag)
const

Properties

etag String
final
file File
final
hashCode int
The hash code for this object.
no setterinherited
mimeType MimeType?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stat FileStat
final

Methods

isStale(FileStat freshStat) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited