isEmpty property
bool
get
isEmpty
Determines if the body is empty by checking the content length.
Implementation
bool get isEmpty => body.contentLength == 0;
Determines if the body is empty by checking the content length.
bool get isEmpty => body.contentLength == 0;