LookupResult<T> class
sealed
Represents the result of looking up a route in the router.
This is a sealed class hierarchy with three possible outcomes:
- RouterMatch: The route was found and matched successfully
- PathMiss: No route exists for the given path
- MethodMiss: A route exists for the path, but not for the HTTP method
- Available extensions
Properties
-
asMatch
→ TrieMatch<
T> -
Available on LookupResult<
Casts this result to a TrieMatch.T> , provided by the LookupResultExtension extensionno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited