connectionInfo property
Information about the IP connection carrying the request.
Be aware that this only contains information about the last leg of the overall HTTP connection, typically from the nearest load balancer to the server.
Implementation
final ConnectionInfo connectionInfo;