RoutingRequestEx extension
Extension on Request providing access to routing information.
These properties are populated when a request is routed using routeWith or RouterHandlerEx.asHandler, and are available to all handlers in the processing chain.
- on
Properties
- matchedPath → NormalizedPath
-
Available on Request, provided by the RoutingRequestEx extension
The portion of the request path that was matched by the route.no setter -
rawPathParameters
→ Map<
Symbol, String> -
Available on Request, provided by the RoutingRequestEx extension
Raw path parameters extracted from the matched route.no setter - remainingPath → NormalizedPath
-
Available on Request, provided by the RoutingRequestEx extension
The portion of the request path that was not consumed by the matched route.no setter - router → RelicRouter?
-
Available on Request, provided by the RoutingRequestEx extension
The RelicRouter that routed this request, if available.no setter